/*
    MicroBlaze(TM) GCC Port for FreeRTOS

    Copyright (C) 2010 Tethers Unlimited, Inc.

    This file is part of the MicroBlaze(TM) GCC port for FreeRTOS.

    The MicroBlaze(TM) GCC port for FreeRTOS is free software: you can
    redistribute it and/or modify it under the terms of the GNU
    General Public License as published by the Free Software
    Foundation, either version 3 of the License, or (at your option)
    any later version.

    The MicroBlaze(TM) GCC port for FreeRTOS is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even
    the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
    PURPOSE. See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the MicroBlaze(TM) GCC port for FreeRTOS. If not, see
    <http://www.gnu.org/licenses/>.
    
    MicroBlaze(TM) is a registered trademark of Xilinx, Inc.

    1 tab == 4 spaces!
*/

/**
 * @file FreeRTOSConfig.h
 * @author Tyrel Newton <newton@tethers.com>, Tethers Unlimited, Inc.
 * @brief Example configuration file for use with FreeRTOS and the MicroBlaze GCC port.
 */

#ifndef FREERTOS_CONFIG_H
#define FREERTOS_CONFIG_H

#include <xparameters.h>

/* General configuration options. */
#define configUSE_PREEMPTION					1
#define configCPU_CLOCK_HZ						( ( unsigned long ) 62500000 )
#define configTICK_RATE_HZ						1000
#define configMAX_PRIORITIES					1
#define configMAX_TASK_NAME_LEN					16
#define configUSE_16_BIT_TICKS					0
#define configIDLE_SHOULD_YIELD					1

/* Stack definitions. */
#define configMINIMAL_STACK_SIZE				1024
#define configSTACK_DEPTH_IN_TCB				1

/* Debugging and error checking. */
#define configCHECK_FOR_STACK_OVERFLOW			1
#define configUSE_TRACE_FACILITY				1
#define configUSE_IDLE_HOOK						0
#define configUSE_TICK_HOOK						1
#define configUSE_MALLOC_FAILED_HOOK			0
#define configGENERATE_RUN_TIME_STATS			0
#define configUSE_APPLICATION_TASK_TAG			0

/* Synchronization primitives. */
#define configUSE_MUTEXES						1
#define configUSE_RECURSIVE_MUTEXES				1
#define configUSE_COUNTING_SEMAPHORES			1

/* Co-routine definitions. */
#define configUSE_CO_ROUTINES					0
#define configMAX_CO_ROUTINE_PRIORITIES			1

/* Set the following definitions to 1 to include the API function, or zero
to exclude the API function. */
#define INCLUDE_vTaskPrioritySet				1
#define INCLUDE_uxTaskPriorityGet				1
#define INCLUDE_uxTaskGetStackHighWaterMark		1
#define INCLUDE_vTaskDelete						1
#define INCLUDE_vTaskCleanUpResources			1
#define INCLUDE_vTaskSuspend					1
#define INCLUDE_vTaskDelayUntil					1
#define INCLUDE_vTaskDelay						1
#define INCLUDE_xTaskResumeFromISR				1
#define INCLUDE_xTaskGetSchedulerState			1

/* Port specific configurations. See portdefs.h. */
#define portGENERATE_ISR_SIGNAL					1
#define portISR_SIGNAL_ADDRESS					XPAR_XPS_GPIO_0_BASEADDR
#define portISR_SIGNAL_MASK						0x00000001
#define portXPS_TIMER_INTERRUPT_ID				XPAR_XPS_INTC_0_XPS_TIMER_0_INTERRUPT_INTR

#endif /* FREERTOS_CONFIG_H */
